@@ -14,7 +14,7 @@ import cloudscraper  # type: ignore
 user_agent = {"User-Agent": "git.io/wanda"}
 content_json = "application/json"
 folder = f"{str(Path.home())}/wanda"
-version = "0.59.8"
+version = "0.59.9"
 
 
 def is_connected():
@@ -162,7 +162,7 @@ def size():
 
     if is_android():
         hxw = command("getprop persist.vendor.camera.display.umax")
-        if blank(hxw):
+        if not blank(hxw):
             return int(hxw.split("x")[1]), int(hxw.split("x")[0])
         return 1440, 2960
     try:
